##############################################################################
#                                                                            #
# Copyright (c) Microsoft Corporation.                                       #
#                                                                            #
# Forefront Protection Server Script Kit (FPSSK)                             #
#                                                                            #
# LICENSED UNDER THE MICROSOFT SOFTWARE LICENSE TERMS PROVIDED WITH THIS     #
# CODE (EULA.RTF). YOUR USE OF THIS CODE IS SUBJECT TO THE TERMS OF THAT     #
# LICENSE. THIS CODE IS PROVIDED *AS IS* WITHOUT WARRANTY OF ANY KIND,       #
# EITHER EXPRESS OR IMPLIED, INCLUDING ANY IMPLIED WARRANTIES OF FITNESS     #
# FOR A PARTICULAR PURPOSE, MERCHANTABILITY, OR NON-INFRINGEMENT.            #
#                                                                            #
##############################################################################

# Globals
$ExportPs1Loaded = $null  # Detect if this script has been loaded

# Export a file on a remote computer and copy the content to a local file
function processExport ($cmdExport, $remoteSrc, $localDest)
{
    $found = $false

    # Run the export action on the remote computer
    $ignored = invokeCommand $cmdExport

    # Get the remote computer's temp file and write it locally
    $remoteFile = invokeCommand "get-content -path $remoteSrc"
    if ($remoteFile -ne $null)
    {
        Out-File `
            -InputObject $remoteFile `
            -FilePath $localDest `
            -ErrorAction:SilentlyContinue

        $found = Test-Path `
                    -LiteralPath $localDest `
                    -PathType Leaf `
                    -ErrorAction:SilentlyContinue
    }
    return $found
}

# Export configuration from a remote computer
function Global:cmdExport ($export, $quiet, $element)
{
    $errorMessage = "Error: Export failed from " + $Global:server.ComputerName
    $date = get-date -uformat "%Y%m%d%H%M%S"
    $export =
        $export + "\FPSSK-Export-" + $Global:server.ComputerName + "-$date"

    # Get the %windir% directory on the remote computer for temp file usage
    $tmpExport = invokeCommand "get-childitem env:windir"
    if ($tmpExport -eq $Null)
    {
        printError $errorMessage
        return
    }

    # Use this temp file on the remote machine for the exported data
    $tmpExport = $tmpExport.Value + "\FPSSK-temp.txt"

    # Create the command string
    $CmdExportXml = "Export-" + $Global:extension + "Settings -Path $tmpExport"

    # If the user only wants a partial configuration dump, add this param
    if ($element -ne $null)
    {
        $element = $element -join ","
        $CmdExportXml = $CmdExportXml + " -Element $element"
    }

    # Export the XML blob
    $xmlFound = processExport $CmdExportXml $tmpExport "$export.xml"

    $CmdExportCsv =
        "Get-" + $Global:extension +
            "ExtendedOption -Name * | Export-Csv $tmpExport -NoTypeInformation"

    # Export the extended options in a CSV format
    $csvFound = processExport $CmdExportCsv $tmpExport "$export.csv"

    # Remove the temporary file on the remote computer, out of kindness
    $ignored = invokeCommand "Remove-Item $tmpExport"

    if (!$quiet -and ($xmlFound -and $csvFound))
    {
        printSuccess "Export success to $export.xml and $export.csv"
    }
    elseif (!$quiet)
    {
        printError $errorMessage
    }

    return $export
}

# This will flag that this script and it's functions have been loaded
$Global:ExportPs1Loaded = $true

# SIG # Begin signature block
# MIIbKAYJKoZIhvcNAQcCoIIbGTCCGxUCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQU6dNNzpMaX9Cs2LZH2IanJ0br
# JmOgghXnMIIEhTCCA22gAwIBAgIKYQX3HgAAAAAAMjANBgkqhkiG9w0BAQUFADB5
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSMwIQYDVQQDExpN
# aWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQTAeFw0wOTA3MTMyMzAwMThaFw0xMDEw
# MTMyMzEwMThaMIGDMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
# MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
# MQ0wCwYDVQQLEwRNT1BSMR4wHAYDVQQDExVNaWNyb3NvZnQgQ29ycG9yYXRpb24w
# ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC1jKmclIRhGswuIsSgk2QJ
# 3oWhsJBd/MlsaLXx7/yOa/T4oG7XUd5goydj1PbftkzSRQunPdhv/u2nGGPTH8aB
# 1L8HN5dAK3/nX1o12ZNPq/MqkvCmjYHsBSTc27hhY1NhAjU41rj17ntUpslYNen0
# Fe/aB2wFLU2ktrqbO7gxMH5FvKmhJTkMQ6RHO5ecIERyN89QoE1N9MNl3ETRCDs4
# 3T7FF2xGx61zJMCPicHq6rrNaKkS1lgMUxYM/jkD1oHyPlxX83rbZuEHGNkZAxT2
# 5kWZKlFMkNda76+3OwwpTW0grge3ki7oacqfMELnwzKKCyJKMuicDMZRAyYBbZJz
# AgMBAAGjggECMIH/MBMGA1UdJQQMMAoGCCsGAQUFBwMDMB0GA1UdDgQWBBSHgbff
# 7vp3+lkFYzcECtfp2qDg4DAOBgNVHQ8BAf8EBAMCB4AwHwYDVR0jBBgwFoAUV0V0
# HF2w9shDBeCMVC2PMqf+SJYwSQYDVR0fBEIwQDA+oDygOoY4aHR0cDovL2NybC5t
# aWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvQ29kZVNpZ1BDQS5jcmwwTQYI
# KwYBBQUHAQEEQTA/MD0GCCsGAQUFBzAChjFodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpL2NlcnRzL0NvZGVTaWdQQ0EuY3J0MA0GCSqGSIb3DQEBBQUAA4IBAQA2
# IYT1j4MhTYeoP4vnxaQPTDBuWXSbC5d0Fqmx83Ckr8IMMyTzoEr6weQhxrbZ6lxb
# kWH3Im3/MfwXTtfNQOOd0uW00vqNbAfad5rKK+4NWUfPBMIQZ/rq6UM7t+bRnNmO
# I2BuEpvD2X5cVzLdlA3ffcVIkk1IdreiwFOVPvw6o5N88oUEx8aFOJc2+BKTIgCZ
# TnmvlutaIIOs0FxaMLAA4ms5jySJ2j0MpEZ5YjZTatfJzZII+4flVPV8WcXEd32w
# wSyYx5dsQ6f4IPiDVGSeYPjiSqVn1Em/VIh9UkTzUcAm0cV88InWEQkowkVFgB2Q
# Ir2OogU+PLNPvdc54IiTMIIEyjCCA7KgAwIBAgIKYQSz9QAAAAAADTANBgkqhkiG
# 9w0BAQUFADB3MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
# A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSEw
# HwYDVQQDExhNaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EwHhcNMDgwNzI1MTkxMzQ1
# WhcNMTEwNzI1MTkyMzQ1WjCBszELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjENMAsGA1UECxMETU9QUjEnMCUGA1UECxMebkNpcGhlciBEU0UgRVNO
# OjlFNzgtODY0Qi0wMzlEMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBT
# ZXJ2aWNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAq0YvvKgU8vhG
# PwwFoaRjRQV/mukzcswn0zLsmMPgNIiFzqESl65IUE5IIH9w5Fkz/JlbuQeASCi8
# jbj6ZgJmtfF/HFCWKJNVjYFVqnBbpcnO7y7i5yXDdm8pC58syFOAmsEN472nRb8x
# 3+aGi32JAYsceFg4st2TSlueHdecxvDETdC/J0oHlARxAogNcOb4KucOYeOYS9Hd
# q1S2N/vGRv2kHLz/r+yyl4DcuJP9uCKonSVZcD5cexxBKf5zmSJJgddVJsDs8k4o
# VGI7cC1hkx1Q1Z8BwgXDVRpKh6QAhlSge2Ky6g/6XVzFKhGCl76GGx2rt6sKKfzM
# zTSJv0C2TwIDAQABo4IBGTCCARUwHQYDVR0OBBYEFKCFMV6Hrg+qCgTr4cDTZL08
# u2n1MB8GA1UdIwQYMBaAFCM0+NlSRnAK7UD7dvuzK7DDNbMPMFQGA1UdHwRNMEsw
# SaBHoEWGQ2h0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3Rz
# L01pY3Jvc29mdFRpbWVTdGFtcFBDQS5jcmwwWAYIKwYBBQUHAQEETDBKMEgGCCsG
# AQUFBzAChjxodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY3Jv
# c29mdFRpbWVTdGFtcFBDQS5jcnQwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDgYDVR0P
# AQH/BAQDAgbAMA0GCSqGSIb3DQEBBQUAA4IBAQBHcU+2SEXACOucL9MlW9tnURGS
# ptnZshSaJsL9BsHM14j1pjW1zSu2a1hqzfmd81rrRi+h+qcffXpCsrDRGgkoVGxv
# mYs4/DrkwSSqckwSBC/x1Hp2O8XPcScLbfw4Z6fFImIre3/BdqynxSZMqa+Y3Yo4
# Xc9lpIEuqe9WAky5CL5lxB6LIS1up/J1ZLTcGmvQ8SXlwueARDnULwp5fgEqp3hb
# o2tbzgnvOTo5t8RnU7mq82H/nXnjz0hn/6vIxitiCZTQH6J493NJO1hTwQmrTAYL
# 1UAofvaxZsW/UsS+Pjvg+Y50jeYiDMHGM5i1eegM9wB86rJOzICaFi3IpBAFMIIG
# BzCCA++gAwIBAgIKYRZoNAAAAAAAHDANBgkqhkiG9w0BAQUFADBfMRMwEQYKCZIm
# iZPyLGQBGRYDY29tMRkwFwYKCZImiZPyLGQBGRYJbWljcm9zb2Z0MS0wKwYDVQQD
# EyRNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkwHhcNMDcwNDAz
# MTI1MzA5WhcNMjEwNDAzMTMwMzA5WjB3MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
# V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
# IENvcnBvcmF0aW9uMSEwHwYDVQQDExhNaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0Ew
# ggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCfoWyx39tIkip8ay4Z4b3i
# 48WZUSNQrc7dGE4kD+7Rp9FMrXQwIBHrB9VUlRVJlBtCkq6YXDAm2gBr6Hu97IkH
# D/cOBJjwicwfyzMkh53y9GccLPx754gd6udOo6HBI1PKjfpFzwnQXq/QsEIEovmm
# bJNn1yjcRlOwhtDlKEYuJ6yGT1VSDOQDLPtqkJAwbofzWTCd+n7Wl7PoIZd++NIT
# 8wi3U21StEWQn0gASkdmEScpZqiX5NMGgUqi+YSnEUcUCYKfhO1VeP4Bmh1QCIUA
# EDBG7bfeI0a7xC1Un68eeEExd8yb3zuDk6FhArUdDbH895uyAc4iS1T/+QXDwiAL
# AgMBAAGjggGrMIIBpzAPBgNVHRMBAf8EBTADAQH/MB0GA1UdDgQWBBQjNPjZUkZw
# Cu1A+3b7syuwwzWzDzALBgNVHQ8EBAMCAYYwEAYJKwYBBAGCNxUBBAMCAQAwgZgG
# A1UdIwSBkDCBjYAUDqyCYEBWJ5flJRP8KuEKU5VZ5KShY6RhMF8xEzARBgoJkiaJ
# k/IsZAEZFgNjb20xGTAXBgoJkiaJk/IsZAEZFgltaWNyb3NvZnQxLTArBgNVBAMT
# JE1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eYIQea0WoUqgpa1M
# c1j0BxMuZTBQBgNVHR8ESTBHMEWgQ6BBhj9odHRwOi8vY3JsLm1pY3Jvc29mdC5j
# b20vcGtpL2NybC9wcm9kdWN0cy9taWNyb3NvZnRyb290Y2VydC5jcmwwVAYIKwYB
# BQUHAQEESDBGMEQGCCsGAQUFBzAChjhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20v
# cGtpL2NlcnRzL01pY3Jvc29mdFJvb3RDZXJ0LmNydDATBgNVHSUEDDAKBggrBgEF
# BQcDCDANBgkqhkiG9w0BAQUFAAOCAgEAEJeKw1wDRDbd6bStd9vOeVFNAbEudHFb
# bQwTq86+e4+4LtQSooxtYrhXAstOIBNQmd16QOJXu69YmhzhHQGGrLt48ovQ7DsB
# 7uK+jwoFyI1I4vBTFd1Pq5Lk541q1YDB5pTyBi+FA+mRKiQicPv2/OR4mS4N9wfi
# cLwYTp2OawpylbihOZxnLcVRDupiXD8WmIsgP+IHGjL5zDFKdjE9K3ILyOpwPf+F
# ChPfwgphjvDXuBfrTot/xTUrXqO/67x9C0J71FNyIe4wyrt4ZVxbARcKFA7S2hSY
# 9Ty5ZlizLS/n+YWGzFFW6J1wlGysOUzU9nm/qhh6YinvopspNAZ3GmLJPR5tH4Lw
# C8csu89Ds+X57H2146SodDW4TsVxIxImdgs8UoxxWkZDFLyzs7BNZ8ifQv+AeSGA
# nhUwZuhCEl4ayJ4iIdBD6Svpu/RIzCzU2DKATCYqSCRfWupW76bemZ3KOm+9gSd0
# BhHudiG/m4LBJ1S2sWo9iaF2YbRuoROmv6pH8BJv/YoybLL+31HIjCPJZr2dHYcS
# ZAI9La9Zj7jkIeW1sMpjtHhUBdRBLlCslLCleKuzoJZ1GtmShxN1Ii8yqAhuoFuM
# Jb+g74TKIdbrHk/Jmu5J4PcBZW+JC33Iacjmbuqnl84xKf8OxVtc2E0bodj6L54/
# LlUWa8kTo/0wggaBMIIEaaADAgECAgphFQgnAAAAAAAMMA0GCSqGSIb3DQEBBQUA
# MF8xEzARBgoJkiaJk/IsZAEZFgNjb20xGTAXBgoJkiaJk/IsZAEZFgltaWNyb3Nv
# ZnQxLTArBgNVBAMTJE1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
# eTAeFw0wNjAxMjUyMzIyMzJaFw0xNzAxMjUyMzMyMzJaMHkxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xIzAhBgNVBAMTGk1pY3Jvc29mdCBDb2Rl
# IFNpZ25pbmcgUENBMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAn43f
# hTeMsQZWZjZO1ArrNiORHq+rjVjpxM/BnzoKJMTExF6w7hUUxfo+mTNrGWly9HwF
# X+WZJUTXNRmKkNwojpAM79WQYa3e3BhwLYPJb6+FLPjdubkw/XF4HIP9yKm5gmcN
# erjBCcK8FpdXPxyY02nXMJCQkI0wH9gm1J57iNniCe2XSUXrBFKBdXu4tSK4Lla7
# 18+pTjwKg6KoOsWttgEOas8itCMfbNUn57d+wbTVMq15JRxChuKdhfRX2htZLy0m
# kinFs9eFo55gWpTme5x7XoI0S23/1O4n0KLc0ZAMzn0OFXyIrDTHwGyYhErJRHlo
# KN8igw24iixIYeL+EQIDAQABo4ICIzCCAh8wEAYJKwYBBAGCNxUBBAMCAQAwHQYD
# VR0OBBYEFFdFdBxdsPbIQwXgjFQtjzKn/kiWMAsGA1UdDwQEAwIBxjAPBgNVHRMB
# Af8EBTADAQH/MIGYBgNVHSMEgZAwgY2AFA6sgmBAVieX5SUT/CrhClOVWeSkoWOk
# YTBfMRMwEQYKCZImiZPyLGQBGRYDY29tMRkwFwYKCZImiZPyLGQBGRYJbWljcm9z
# b2Z0MS0wKwYDVQQDEyRNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3Jp
# dHmCEHmtFqFKoKWtTHNY9AcTLmUwUAYDVR0fBEkwRzBFoEOgQYY/aHR0cDovL2Ny
# bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvbWljcm9zb2Z0cm9vdGNl
# cnQuY3JsMFQGCCsGAQUFBwEBBEgwRjBEBggrBgEFBQcwAoY4aHR0cDovL3d3dy5t
# aWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNyb3NvZnRSb290Q2VydC5jcnQwdgYD
# VR0gBG8wbTBrBgkrBgEEAYI3FS8wXjBcBggrBgEFBQcCAjBQHk4AQwBvAHAAeQBy
# AGkAZwBoAHQAIACpACAAMgAwADAANgAgAE0AaQBjAHIAbwBzAG8AZgB0ACAAQwBv
# AHIAcABvAHIAYQB0AGkAbwBuAC4wEwYDVR0lBAwwCgYIKwYBBQUHAwMwDQYJKoZI
# hvcNAQEFBQADggIBADC8sCCkYqCn7zkmYT3crMaZ0IbELvWDMmVeIj6b1ob46Laf
# yovWO3ULoZE+TN1kdIxJ8oiMGGds/hVmRrg6RkKXyJE31CSx56zT6kEUg3fTyU8F
# X6MUUr+WpC8+VlsQdc5Tw84FVGm0ZckkpQ/hJbgauU3lArlQHk+zmAwdlQLuIlmt
# IssFdAsERXsEWeDYD7PrTPhg3cJ4ntG6n2v38+5+RBFA0r26m0sWCG6kvlXkpjgS
# o0j0HFV6iiDRff6R25SPL8J7a6ZkhU+j5Sw0KV0Lv/XHOC/EIMRWMfZpzoX4CpHs
# 0NauujgFDOtuT0ycAymqovwYoCkMDVxcViNX2hyWDcgmNsFEy+Xh5m+J54/pmLVz
# 03jj7aMBPHTlXrxs9iGJZwXsl521sf2vpulypcM04S+f+fRqOeItBIJb/NCcrnyd
# EfnmtVMZdLo5SjnrfUKzSjs3PcJKeyeY5+JOmxtKVDhqIze+ardI7upCDUkkkY63
# BC6Xb+TnRbuPTf1g2ddZwtiA1mA0e7ehkyD+gbiqpVwJ6YoNvihNftfoD+1leNEx
# X7lm299C5wvMAgeN3/8gBqNFZbSzMo0ukeJNtKnJ+rxrBA6yn+qf3qTJCpb0jffY
# mKjwhQIIWaQgpiwLGvJSBu1p5WQYG+Cjq97KfBRhQ7hl9TajVRMrZyxNGzBMMYIE
# qzCCBKcCAQEwgYcweTELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEjMCEGA1UEAxMaTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0ECCmEF9x4AAAAA
# ADIwCQYFKw4DAhoFAKCB2DAZBgkqhkiG9w0BCQMxDAYKKwYBBAGCNwIBBDAcBgor
# BgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkqhkiG9w0BCQQxFgQUmXlcFB/D
# J5zodZ1FTBdsVoXpOvcweAYKKwYBBAGCNwIBDDFqMGigToBMAEYAbwByAGUAZgBy
# AG8AbgB0ACAAUAByAG8AdABlAGMAdABpAG8AbgAgAFMAZQByAHYAZQByACAAUwBj
# AHIAaQBwAHQAIABLAGkAdKEWgBRodHRwOi8vbWljcm9zb2Z0LmNvbTANBgkqhkiG
# 9w0BAQEFAASCAQApS1z+mDUiSNRBjqYLRQ3zQVhntXP/rfRPHD4GRDGaivZAJXzY
# ywfXYNGw9P6CydNTWD7RDt9QQdb7UzWvXbRhO0QAUR3SUCefA8YjAkSX9kw8wp7M
# 4nlPwh8mXj6DxKVfQItc80UMXTewoq1tkCj+UGprCZBMcM2Fwjh6qwNU7HaiOH7J
# cwsTn+SsoG9UIsXxRInkcno5aM5t8jWEWuukHLZqbJvl+w3Nwo9coroTBiLGDWXj
# EPLNdU2O6SxpYCJzsjHVqBhSYRDGr4AOUwu6S1xfSaYq6ZZU4ZmFnT3lH5Jz0A2a
# YWndErn5lWxcX2qFlpu4owIE8Rwn1h4eEO1xoYICHTCCAhkGCSqGSIb3DQEJBjGC
# AgowggIGAgEBMIGFMHcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xITAfBgNVBAMTGE1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQQIKYQSz9QAAAAAA
# DTAHBgUrDgMCGqBdMBgGCSqGSIb3DQEJAzELBgkqhkiG9w0BBwEwHAYJKoZIhvcN
# AQkFMQ8XDTEwMDcyNzIyNTUxNlowIwYJKoZIhvcNAQkEMRYEFFkAbuFJbEv0SctO
# 1YxVcW6I6+0tMA0GCSqGSIb3DQEBBQUABIIBAJGPF2Aor7X1pEUb2w2/4X0y65mQ
# kdA2zcgdF95V7BSwWy3fqQKUy3oKBY6PeD01xXyRql/VUHDFy4wTYK/AAVH45ujJ
# M8tPoI8O5cXk9doiYIARK/XOSfL64mRkP6HAhiBBTd1DDhm1oodP1Bmn8ydHHD6i
# g9qgURp5bo0LoZElwHhyuSIM9X4P0VZgwTN6RwQBr4XNQznh+9x98EdMXzGtk/Av
# NjAIfALPUT1kPSmMr9kI0iuJ7upfoND0HgSmevtdlRL0UYFar2P3JiUtwd7LwNnS
# EVP+I4NoAtuG2GR9bcfCgWV1ydKPV5MsZsMhsSLR23QpdRS6uvuNXMno0Qc=
# SIG # End signature block
